@@ -8,7 +8,7 @@ HIRA_TO_LATN = {
     "さ": "sa", "し": "shi", "す": "su", "せ": "se", "そ": "so",
     "ざ": "za", "じ": "ji", "ず": "zu", "ぜ": "ze", "ぞ": "zo",
     "た": "ta", "ち": "chi", "つ": "tsu", "て": "te", "と": "to",
-    "だ": "da", "づ": "zu", "で": "de", "ど": "do",
+    "だ": "da", 'ぢ': 'ji', "づ": "zu", "で": "de", "ど": "do",
     "な": "na", "に": "ni", "ぬ": "nu", "ね": "ne", "の": "no",
     "は": "ha", "ひ": "hi", "ふ": "fu", "へ": "he", "ほ": "ho",
     "ば": "ba", "び": "bi", "ぶ": "bu", "べ": "be", "ぼ": "bo",
@@ -51,8 +51,6 @@ HIRA_TO_LATN = {
     "しぇ": "she", "じぇ": "je",
 
     "ちぇ": "che", "すぇ": "swe", "りぇ": "riye", "るぇ": "ruye", "くぇ": "kwe", "いぇ": "ye",
-
-    "ちぢ": "chidi"
 }
 
 LATN_TO_HIRA = {
@@ -96,18 +94,16 @@ LATN_TO_HIRA = {
     'g': 'っ', 'z': 'っ', 'd': 'っ', 'b': 'っ', 'p': 'っ',
     'qi': '々', '・': '',
 
-    "ua": "うぁ", "wi": "うぃ", "wu": "うぅ", "we": "うぇ", "uo": "うぉ",
-    "va": "ゔぁ", "vi": "ゔぃ", "ve": "ゔぇ", "vo": "ゔぉ", "vyu": "ゔゅ",
-
-    "fa": "ふぁ", "fi": "ふぃ", "fe": "ふぇ", "fo": "ふぉ", "fyu": "ふゅ",
-
-    "ti": "てぃ", "di": "でぃ", "dyu": "でゅ",
-
-    "tsa": "つぁ", "tse": "つぇ",
-
-    "she": "しぇ", "je": "じぇ",
-
-    "che": "ちぇ", "swe": "すぇ", "riye": "りぇ", "ruye": "るぇ", "kwe": "くぇ", "ye": "いぇ",
-
-    "chidi": "ちぢ"
+    # "ua": "うぁ", "wi": "うぃ", "wu": "うぅ", "we": "うぇ", "uo": "うぉ",
+    # "va": "ゔぁ", "vi": "ゔぃ", "ve": "ゔぇ", "vo": "ゔぉ", "vyu": "ゔゅ",
+    #
+    # "fa": "ふぁ", "fi": "ふぃ", "fe": "ふぇ", "fo": "ふぉ", "fyu": "ふゅ",
+    #
+    # "ti": "てぃ", "di": "でぃ", "dyu": "でゅ",
+    #
+    # "tsa": "つぁ", "tse": "つぇ",
+    #
+    # "she": "しぇ", "je": "じぇ",
+    #
+    # "che": "ちぇ", "swe": "すぇ", "riye": "りぇ", "ruye": "るぇ", "kwe": "くぇ", "ye": "いぇ",
 }
